@@ -254,7 +254,10 @@ class Lab:
 
                 ax.plot(d.stretch, stress_stable, **lineargs[d.label], label=d.label)
                 ax.plot(
-                    d.stretch, stress_unstable, **lineargs[d.label], linestyle="--",
+                    d.stretch,
+                    stress_unstable,
+                    **lineargs[d.label],
+                    linestyle="--",
                 )
 
             else:
